@@ -791,23 +791,18 @@ xfconf_cache_lookup_locked(XfconfCache *cache,
                 g_free(error_name);
             }
 
-            if (!item) {
-                g_propagate_error(error, tmp_error);
-            } else {
-                g_error_free(tmp_error);
-            }
+            g_propagate_error(error, tmp_error);
         }
     }
 
     if(item) {
         if (item->value == NULL) {
-            gchar *message = g_strdup_printf(_("Property \"%s\" does not exist on channel \"%s\""),
-                                             property, cache->channel_name);
-            g_dbus_error_set_dbus_error(error,
-                                        XFCONF_SERVICE_NAME_PREFIX ".Xfconf.Error.PropertyNotFound",
-                                        message,
-                                        NULL);
-            g_free(message);
+            g_set_error(error,
+                        XFCONF_ERROR,
+                        XFCONF_ERROR_PROPERTY_NOT_FOUND,
+                        _("Property \"%s\" does not exist on channel \"%s\""),
+                        property,
+                        cache->channel_name);
         } else if(value) {
             if(!G_VALUE_TYPE(value))
                 g_value_init(value, G_VALUE_TYPE(item->value));
@@ -952,7 +947,9 @@ xfconf_cache_set(XfconfCache *cache,
         g_hash_table_insert(cache->pending_calls, old_item->cancellable, old_item);
 
         if(item) {
-            xfconf_cache_item_update(item, value);
+            if (item->value != NULL) {
+                xfconf_cache_item_update(item, value);
+            }
         } else {
             item = xfconf_cache_item_new(value, FALSE);
             g_tree_insert(cache->properties, g_strdup(property), item);
